herosdevices - Heros Devices 0.6.0 documentation

Skip to content
Back to top
View this page

# herosdevices

This package contains python representations (think drivers) of frequently used lab equipment.

While these drivers can be perfectly used also locally on the system attached to the lab equipment, the real advantage arises, when the created python object is made available in the network via HEROS. The drivers in this repository sit in the hardware submodule and are arranged in submodules corresponding the vendor name of the device.

## Submodules

- herosdevices.core
- herosdevices.hardware
- herosdevices.helper
- herosdevices.interfaces